@@ -552,20 +552,23 @@ ancovaClass <- R6::R6Class(
                 dummy <- contr.treatment(levels)
                 dimnames(dummy) <- NULL
                 coding <- matrix(rep(1/nLevels, prod(dim(dummy))), ncol=nLevels-1)
-                contrast <- (dummy - coding) * nLevels
+                contrast <- (dummy - coding)
 
             } else if (type == 'deviation') {
 
                 contrast <- matrix(0, nrow=nLevels, ncol=nLevels-1)
 
                 for (i in seq_len(nLevels-1)) {
-                    contrast[i+1, i] <- -1
-                    contrast[1, i] <- 1
+                    contrast[i+1, i] <- 1
+                    contrast[1, i] <- -1
                 }
 
             } else if (type == 'difference') {
 
                 contrast <- stats::contr.helmert(levels)
+                for (i in 1:ncol(contrast))
+                    contrast[,i] <- contrast[,i] / (i + 1)
+
                 dimnames(contrast) <- NULL
 
             } else if (type == 'helmert') {
@@ -578,8 +581,6 @@ ancovaClass <- R6::R6Class(
                     contrast[(i+1):nLevels,i] <- -p
                 }
 
-                contrast
-
             } else if (type == 'polynomial') {
 
                 contrast <- stats::contr.poly(levels)
@@ -589,8 +590,8 @@ ancovaClass <- R6::R6Class(
 
                 contrast <- matrix(0, nrow=nLevels, ncol=nLevels-1)
                 for (i in seq_len(nLevels-1)) {
-                    contrast[i,  i] <- 1
-                    contrast[i+1,i] <- -1
+                    contrast[1:i,i] <- (nLevels-i) / nLevels
+                    contrast[(i+1):nLevels,i] <- -i / nLevels
                 }
 
             } else {
